@@ -34,14 +34,17 @@ __protobuf__ = proto.module(
         'GlobalTonnageZoneCount',
         'GetTonnageFleetRequest',
         'GetTonnageFleetStatusResponse',
-        'GetTonnageFleetDevelopmentResponse',
-        'FleetTimeseriesGroup',
-        'FleetDevelopmentTimeseriesRow',
+        'GetTonnageFleetGrowthResponse',
+        'FleetGrowthTimeseriesGroup',
+        'FleetGrowthTimeseriesRow',
+        'TimeseriesGroup',
         'TimeseriesRow',
         'TonnageChineseWatersRequest',
         'TonnageChineseWatersResponse',
         'ChineseWatersTimeseriesGroup',
         'ChineseWatersTimeseriesRow',
+        'GetTonnageZoneChangesRequest',
+        'GetTonnageZoneChangesResponse',
         'EmptyParams',
         'EmptyResponse',
     },
@@ -66,20 +69,19 @@ class GetTonnageDataRequest(proto.Message):
             be obtained from the **/entities/segments** endpoint. Cannot
             be supplied alongside segment
         direction (Sequence[str]):
-            List of vessel sub segments to filter on. Allowed values can
-            be obtained from the **/entities/segments** endpoint. Cannot
-            be supplied alongside segment.
-        laden_status (Sequence[str]):
             The list of directions to get tonnage data for. The
             following directions are allowed:
             **["NNE","ENE","ESE","SSE","SSW","WSW","WNW","NNW"]**.
             Directions can also be obtained from the interactive
             direction selector found at app.oceanbolt.com.
+        laden_status (Sequence[str]):
+            The laden status to get tonnage data for. The following
+            values are allowed: **["laden","ballast"]**.
         port_status (Sequence[str]):
             The port status to get tonnage data for. The following
             values are allowed: **["in_port","at_sea"]**.
         group_by (str):
-
+            Not Implemented Yet //TODO
         exclude_mpv (bool):
             Flag to specify whether or not MPV vessels
             should be included/excluded. Default is to
@@ -150,15 +152,17 @@ class GetTonnageZoneCountResponse(proto.Message):
 
 
 class GetFleetSpeedResponse(proto.Message):
-    r"""
+    r"""Response object for FleetSpeed
 
     Attributes:
         timeseries (Sequence[oceanbolt.com.tonnage_v3.types.TonnageTimeseriesGroup]):
-
+            Timeseries data groups
         csv (str):
-
+            Link to download csv file, if format was
+            specified to be "csv".
         xlsx (str):
-
+            Link to download excel file, if format was
+            specified to be "xlsx".
     """
 
     timeseries = proto.RepeatedField(proto.MESSAGE, number=1,
@@ -171,7 +175,7 @@ class GetFleetSpeedResponse(proto.Message):
 
 
 class TonnageTimeseriesGroup(proto.Message):
-    r"""Tonnage zone timeseries group
+    r"""Tonnage zone/fleet speed timeseries group
 
     Attributes:
         group (str):
@@ -189,7 +193,7 @@ class TonnageTimeseriesGroup(proto.Message):
 
 
 class TonnageTimeseriesRow(proto.Message):
-    r"""
+    r"""Tonnage zone/fleet speed timeseries row
 
     Attributes:
         date (str):
@@ -318,58 +322,82 @@ class GlobalTonnageZoneCount(proto.Message):
 
 
 class GetTonnageFleetRequest(proto.Message):
-    r"""GetTonnageFleet
+    r"""Request object for GetTonnageFleetStatus and
+    GetTonnageFleetGrowth
 
     Attributes:
-        range_ (str):
-
+        frequency (str):
+            Frequency determines the granularity/period grouping of the
+            timeseries. Allowed values are: **["daily", "weekly",
+            "monthly","quarterly "yearly"]**. Default value is
+            "monthly".
         segment (Sequence[str]):
-
+            List of vessel segments to filter on. Allowed values can be
+            obtained from the **/entities/segments** endpoint. Cannot be
+            supplied alongside subSegment
         sub_segment (Sequence[str]):
-
-        group (str):
-
+            List of vessel sub segments to filter on. Allowed values can
+            be obtained from the **/entities/segments** endpoint. Cannot
+            be supplied alongside segment
+        group_by (str):
+            Determines the grouping of the timeseries
+            data.
         metric (str):
-
+            The metric to retrieve for timeseries aggregations. Allowed
+            values: ["count","dwt"]. Default is "count".
         format_ (str):
-
-        excludeMpv (bool):
-
+            The return format of the data ["csv","json", "xlsx"].
+            Default is "json".
+        exclude_mpv (bool):
+            Flag to specify whether or not MPV vessels
+            should be included/excluded. Default is to
+            include.
         sort (str):
-
+            Specifies whether results should be sorted in ascending or
+            descing order. Allowed values: ["asc","desc"].
+        start_date (str):
+            The UTC start date of the date filter
+        end_date (str):
+            The UTC end date of the date filter
     """
 
-    range_ = proto.Field(proto.STRING, number=1)
+    frequency = proto.Field(proto.STRING, number=1)
 
     segment = proto.RepeatedField(proto.STRING, number=2)
 
     sub_segment = proto.RepeatedField(proto.STRING, number=6)
 
-    group = proto.Field(proto.STRING, number=3)
+    group_by = proto.Field(proto.STRING, number=3)
 
     metric = proto.Field(proto.STRING, number=4)
 
     format_ = proto.Field(proto.STRING, number=5)
 
-    excludeMpv = proto.Field(proto.BOOL, number=7)
+    exclude_mpv = proto.Field(proto.BOOL, number=7)
 
     sort = proto.Field(proto.STRING, number=8)
 
+    start_date = proto.Field(proto.STRING, number=9)
+
+    end_date = proto.Field(proto.STRING, number=10)
+
 
 class GetTonnageFleetStatusResponse(proto.Message):
-    r"""
+    r"""Response object for GetTonnageFleetStatus
 
     Attributes:
-        data (Sequence[oceanbolt.com.tonnage_v3.types.TimeseriesRow]):
-
+        timeseries (Sequence[oceanbolt.com.tonnage_v3.types.TimeseriesGroup]):
+            Timeseries data groups
         csv (str):
-
+            Link to download csv file, if format was
+            specified to be "csv".
         xlsx (str):
-
+            Link to download excel file, if format was
+            specified to be "xlsx".
     """
 
-    data = proto.RepeatedField(proto.MESSAGE, number=1,
-        message='TimeseriesRow',
+    timeseries = proto.RepeatedField(proto.MESSAGE, number=1,
+        message='TimeseriesGroup',
     )
 
     csv = proto.Field(proto.STRING, number=2)
@@ -377,20 +405,22 @@ class GetTonnageFleetStatusResponse(proto.Message):
     xlsx = proto.Field(proto.STRING, number=3)
 
 
-class GetTonnageFleetDevelopmentResponse(proto.Message):
-    r"""
+class GetTonnageFleetGrowthResponse(proto.Message):
+    r"""Response object for GetTonnageFleetGrowth
 
     Attributes:
-        data (Sequence[oceanbolt.com.tonnage_v3.types.FleetTimeseriesGroup]):
-
+        timeseries (Sequence[oceanbolt.com.tonnage_v3.types.FleetGrowthTimeseriesGroup]):
+            Timeseries data groups
         csv (str):
-
+            Link to download csv file, if format was
+            specified to be "csv".
         xlsx (str):
-
+            Link to download excel file, if format was
+            specified to be "xlsx".
     """
 
-    data = proto.RepeatedField(proto.MESSAGE, number=1,
-        message='FleetTimeseriesGroup',
+    timeseries = proto.RepeatedField(proto.MESSAGE, number=1,
+        message='FleetGrowthTimeseriesGroup',
     )
 
     csv = proto.Field(proto.STRING, number=2)
@@ -398,35 +428,40 @@ class GetTonnageFleetDevelopmentResponse(proto.Message):
     xlsx = proto.Field(proto.STRING, number=3)
 
 
-class FleetTimeseriesGroup(proto.Message):
-    r"""
+class FleetGrowthTimeseriesGroup(proto.Message):
+    r"""Fleet growth timeseries group
 
     Attributes:
         group (str):
-
-        rows (Sequence[oceanbolt.com.tonnage_v3.types.FleetDevelopmentTimeseriesRow]):
-
+            Name of the group. This will be "default", if
+            no grouping was specified in the query.
+        rows (Sequence[oceanbolt.com.tonnage_v3.types.FleetGrowthTimeseriesRow]):
+            Rows of timeseries data
     """
 
     group = proto.Field(proto.STRING, number=1)
 
     rows = proto.RepeatedField(proto.MESSAGE, number=2,
-        message='FleetDevelopmentTimeseriesRow',
+        message='FleetGrowthTimeseriesRow',
     )
 
 
-class FleetDevelopmentTimeseriesRow(proto.Message):
-    r"""
+class FleetGrowthTimeseriesRow(proto.Message):
+    r"""Fleet growth timeseries row
 
     Attributes:
         date (str):
-
+            UTC date timestamp of the timeseries row
         scrapped (google.protobuf.wrappers_pb2.DoubleValue):
-
+            Number of vessels (or sum of DWT) that was
+            scrapped during this period
         delivered (google.protobuf.wrappers_pb2.DoubleValue):
-
+            Number of vessels (or sum of DWT) that was
+            delivered during this period
         net (google.protobuf.wrappers_pb2.DoubleValue):
-
+            Net number of vessels (or sum of DWT) that
+            was added to/removed from the fleet during this
+            period
     """
 
     date = proto.Field(proto.STRING, number=1)
@@ -444,16 +479,32 @@ class FleetDevelopmentTimeseriesRow(proto.Message):
     )
 
 
+class TimeseriesGroup(proto.Message):
+    r"""Generic tonnage timeseries group
+
+    Attributes:
+        group (str):
+            Name of the group. This will be "default", if
+            no grouping was specified in the query.
+        rows (Sequence[oceanbolt.com.tonnage_v3.types.TimeseriesRow]):
+            Rows of timeseries data
+    """
+
+    group = proto.Field(proto.STRING, number=1)
+
+    rows = proto.RepeatedField(proto.MESSAGE, number=2,
+        message='TimeseriesRow',
+    )
+
+
 class TimeseriesRow(proto.Message):
-    r"""
+    r"""Genericg tonnage timeseries row
 
     Attributes:
         date (str):
-
+            UTC date timestamp of the timeseries row
         value (google.protobuf.wrappers_pb2.DoubleValue):
 
-        group (str):
-
     """
 
     date = proto.Field(proto.STRING, number=1)
@@ -462,27 +513,32 @@ class TimeseriesRow(proto.Message):
         message=wrappers.DoubleValue,
     )
 
-    group = proto.Field(proto.STRING, number=3)
-
 
 class TonnageChineseWatersRequest(proto.Message):
-    r"""Tonnage Chinese Waters
+    r"""Request object for TonnageChineseWaters
 
     Attributes:
         start_date (str):
-
+            The UTC start date of the date filter
         end_date (str):
-
+            The UTC end date of the date filter
         segment (Sequence[str]):
-
+            List of vessel segments to filter on. Allowed values can be
+            obtained from the **/entities/segments** endpoint. Cannot be
+            supplied alongside subSegment
         sub_segment (Sequence[str]):
-
+            List of vessel sub segments to filter on. Allowed values can
+            be obtained from the **/entities/segments** endpoint. Cannot
+            be supplied alongside segment
         group_by (str):
-
+            Determines the grouping of the timeseries
+            data.
         sort (str):
-
+            Specifies whether results should be sorted in ascending or
+            descing order. Allowed values: ["asc","desc"].
         format_ (str):
-
+            The return format of the data ["csv","json", "xlsx"].
+            Default is "json".
     """
 
     start_date = proto.Field(proto.STRING, number=1)
@@ -501,7 +557,7 @@ class TonnageChineseWatersRequest(proto.Message):
 
 
 class TonnageChineseWatersResponse(proto.Message):
-    r"""
+    r"""Response object for TonnageChineseWaters
 
     Attributes:
         timeseries (Sequence[oceanbolt.com.tonnage_v3.types.ChineseWatersTimeseriesGroup]):
@@ -543,7 +599,7 @@ class ChineseWatersTimeseriesRow(proto.Message):
 
     Attributes:
         date (str):
-
+            UTC date timestamp of the timeseries row
         inside_chinese_waters_count (google.protobuf.wrappers_pb2.Int32Value):
 
         inside_chinese_waters_dwt (google.protobuf.wrappers_pb2.DoubleValue):
@@ -573,6 +629,89 @@ class ChineseWatersTimeseriesRow(proto.Message):
     )
 
 
+class GetTonnageZoneChangesRequest(proto.Message):
+    r"""Request object for TonnageZoneChange
+
+    Attributes:
+        from_zone_id (Sequence[int]):
+
+        to_zone_id (Sequence[int]):
+
+        segment (Sequence[str]):
+            List of vessel segments to filter on. Allowed values can be
+            obtained from the **/entities/segments** endpoint. Cannot be
+            supplied alongside subSegment
+        sub_segment (Sequence[str]):
+            List of vessel sub segments to filter on. Allowed values can
+            be obtained from the **/entities/segments** endpoint. Cannot
+            be supplied alongside segment
+        laden_status (Sequence[str]):
+            The laden status to get tonnage data for. The following
+            values are allowed: **["laden","ballast"]**.
+        start_date (str):
+            The UTC start date of the date filter
+        end_date (str):
+            The UTC end date of the date filter
+        group_by (str):
+            Determines the grouping of the timeseries
+            data.
+        sort (str):
+            Specifies whether results should be sorted in ascending or
+            descing order. Allowed values: ["asc","desc"].
+        format_ (str):
+            The return format of the data ["csv","json", "xlsx"].
+            Default is "json".
+        frequency (str):
+            Frequency determines the granularity/period grouping of the
+            timeseries. Allowed values are: **["daily", "weekly",
+            "monthly","quarterly "yearly"]**. Default value is
+            "monthly".
+    """
+
+    from_zone_id = proto.RepeatedField(proto.INT32, number=1)
+
+    to_zone_id = proto.RepeatedField(proto.INT32, number=2)
+
+    segment = proto.RepeatedField(proto.STRING, number=3)
+
+    sub_segment = proto.RepeatedField(proto.STRING, number=4)
+
+    laden_status = proto.RepeatedField(proto.STRING, number=5)
+
+    start_date = proto.Field(proto.STRING, number=6)
+
+    end_date = proto.Field(proto.STRING, number=7)
+
+    group_by = proto.Field(proto.STRING, number=8)
+
+    sort = proto.Field(proto.STRING, number=9)
+
+    format_ = proto.Field(proto.STRING, number=10)
+
+    frequency = proto.Field(proto.STRING, number=11)
+
+
+class GetTonnageZoneChangesResponse(proto.Message):
+    r"""Response object for TonnageZoneChange
+
+    Attributes:
+        timeseries (Sequence[oceanbolt.com.tonnage_v3.types.TimeseriesGroup]):
+
+        csv (str):
+
+        xlsx (str):
+
+    """
+
+    timeseries = proto.RepeatedField(proto.MESSAGE, number=1,
+        message='TimeseriesGroup',
+    )
+
+    csv = proto.Field(proto.STRING, number=2)
+
+    xlsx = proto.Field(proto.STRING, number=3)
+
+
 class EmptyParams(proto.Message):
     r""""""
 
