@@ -31,6 +31,10 @@ __all__ = (
     'TradeFlows',
     'TonnageZoneTimeseries',
     'FleetSpeedTimeseries',
+    'TonnageZoneChangesTimeseries',
+    'ChineseWatersTimeseries',
+    'FleetStatusTimeseries',
+    'FleetGrowthTimeseries',
     'Ports',
     'Zones',
     'Segments',
